ini

package
v0.0.0-...-0dfd486 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 3, 2015 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package ini defines a loader for ini config files

autoconfig.Load(ini.New(filename))

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Loader

type Loader struct {
	// contains filtered or unexported fields
}

func New

func New(filename string) *Loader

New creates a Loader for INI files

func (*Loader) Load

func (l *Loader) Load(cfg map[string]interface{}) error

Load loads the config file and unmarshals it to cfg

Jump to